/*!
Linear Technology DCXXXX Demonstration Board
LTC5555: Programmable Downconverting Mixer with IF DVGA

@verbatim

The LTC5555 programmable gain downconverting mixer is ideal
for receivers that require precise gain setting. The IC 
incorporates an active mixer and a digital IF VGA with
15.5dB gain control range. The IF gain is programmed in
0.5dB steps through the SPI or parallel interface. 
A reduced power mode is also available.


@endverbatim

https://www.analog.com/en/products/ltc5555.html??????

Copyright 2019(c) Analog Devices, Inc.

All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
 - Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
 - Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.
 - Neither the name of Analog Devices, Inc. nor the names of its
   contributors may be used to endorse or promote products derived
   from this software without specific prior written permission.
 - The use of this software may or may not infringe the patent rights
   of one or more patent holders.  This license does not release you
   from the requirement that you obtain separate licenses from these
   patent holders to use this software.
 - Use of the software either in source or binary form, must be run
   on or directly connected to an Analog Devices Inc. component.

THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/*! @file
    @ingroup LTC5555
*/

#include "LTC5555.h"
#include <SPI.h>
#include "LT_SPI.h"
#include "UserInterface.h"
#include "Linduino.h"

// Function Declarations

// Print the title block
void LTC5555_print_title();

// Print the initial prompt
void LTC5555_print_prompt();


//! Initialize Linduino
//! @return void
void setup() {
  // Configure the SPI port for 4MHz SCK
  quikeval_SPI_init();

  // Initialize the serial port to the PC and setting the timeout
  Serial.begin(115200);
  Serial.setTimeout(100);

  // Displays the title
  LTC5555_print_title();

  // Displays the initial prompt
  LTC5555_print_prompt();
}


//! Repeats Linduino loop
//! @return void
void loop() {

  // The register value read back from the LTC5555
  uint8_t output_register;
  if (Serial.available()) {
    //clearing uart receive buffer
    Serial.readString(); 

    // Run the duplicate settings function
    output_register = LTC5555_settings();
    Serial.println(F("\nLTC5555 settings:"));

    // Decode the resulting value
    LTC5555_decode_output(output_register);

    Serial.println(F("\n*****************************************************************\n\n"));
    LTC5555_print_prompt();
  }
}

//! Prints the title block
//! @return void
void LTC5555_print_title() {
  Serial.println(F("*****************************************************************"));
  Serial.println(F("* DCXXXXX Demonstration Program                                 *"));
  Serial.println(F("*                                                               *"));
  Serial.println(F("* This program demonstrates how to send data to the LTC5555.    *"));
  Serial.println(F("*****************************************************************"));
}

//! Prints the initial prompt
//! @return void
void LTC5555_print_prompt() {
  Serial.println(F("Enter any key to configure the mixer"));
}
